<?php
/**
 * Catch Everest Custom meta box
 *
 * @package Catch Themes
 * @subpackage Catch_Everest
 * @since Catch Everest 1.0
 */

 // Add the Meta Box
function catcheverest_add_custom_box() {
	add_meta_box(
		'catcheverest-options',							  	//Unique ID
        esc_html__( 'Catch Everest Options', 'catch-everest-pro' ),   	//Title
        'catcheverest_meta_options',                   	//Callback function
        array( 'page', 'post' ),                                        	//show metabox in page
    	'side'
    );
}
add_action( 'add_meta_boxes', 'catcheverest_add_custom_box' );

/**
 * @renders metabox to for sidebar layout
 */
function catcheverest_meta_options() {
    global $post;

    //Header Featured Image Options
	$header_image_options = array(
		'default' => array(
			'id'		=> 'catcheverest-header-image',
			'value' 	=> 'default',
			'label' 	=> esc_html__( 'Default', 'catch-everest-pro' ),
		),
		'enable' => array(
			'id'		=> 'catcheverest-header-image',
			'value' 	=> 'enable',
			'label' 	=> esc_html__( 'Enable', 'catch-everest-pro' ),
		),
		'disable' => array(
			'id'		=> 'catcheverest-header-image',
			'value' 	=> 'disable',
			'label' 	=> esc_html__( 'Disable', 'catch-everest-pro' )
		)
	);

	//Sidebar Layout Options
	$sidebar_layout = array(
		'default-sidebar' => array(
			'id'        => 'catcheverest-sidebarlayout',
			'value'     => 'default',
			'label'     => esc_html__( 'Default (Set in Customizer Options)', 'catch-everest-pro' ),
		),
       'right-sidebar' => array(
			'id'        => 'catcheverest-sidebarlayout',
			'value'     => 'right-sidebar',
			'label'     => esc_html__( 'Right sidebar', 'catch-everest-pro' ),
		),
        'left-sidebar' => array(
			'id'        => 'catcheverest-sidebarlayout',
			'value'     => 'left-sidebar',
			'label'     => esc_html__( 'Left sidebar', 'catch-everest-pro' ),
		),
        'no-sidebar' => array(
			'id'		=> 'catcheverest-sidebarlayout',
			'value' 	=> 'no-sidebar',
			'label' 	=> esc_html__( 'No sidebar', 'catch-everest-pro' ),
		),
		'no-sidebar-full-width' => array(
			'id'		=> 'catcheverest-sidebarlayout',
			'value' 	=> 'no-sidebar-full-width',
			'label' 	=> esc_html__( 'No sidebar, Full Width', 'catch-everest-pro' ),
		),
        'no-sidebar-one-column' => array(
			'id'		=> 'catcheverest-sidebarlayout',
			'value' 	=> 'no-sidebar-one-column',
			'label' 	=> esc_html__( 'No Sidebar, One Column', 'catch-everest-pro' ),
		)
    );

	//Sidebar Options
	$sidebar_options = array(
		'main-sidebar' => array(
			'id'		=> 'catcheverest-sidebar-options',
			'value' 	=> 'default-sidebar',
			'label' 	=> esc_html__( 'Default Sidebar', 'catch-everest-pro' )
		),
		'optional-sidebar-one' => array(
			'id' => 'catcheverest-sidebar-options',
			'value' => 'optional-sidebar-one',
			'label' => esc_html__( 'Optional Sidebar One', 'catch-everest-pro' )
		),
		'optional-sidebar-two' => array(
			'id' => 'catcheverest-sidebar-options',
			'value' => 'optional-sidebar-two',
			'label' => esc_html__( 'Optional Sidebar Two', 'catch-everest-pro' )
		),
		'optional-sidebar-three' => array(
			'id' => 'catcheverest-sidebar-options',
			'value' => 'optional-sidebar-three',
			'label' => esc_html__( 'Optional Sidebar three', 'catch-everest-pro' )
		)
	);

	//Featured Image Options
	$featuredimage_options = array(
		'default' => array(
			'id'		=> 'catcheverest-featured-image',
			'value' 	=> 'default',
			'label' 	=> esc_html__( 'Default (Set in Customizer Options)', 'catch-everest-pro' ),
		),
		'featured' => array(
			'id'		=> 'catcheverest-featured-image',
			'value' 	=> 'featured',
			'label' 	=> esc_html__( 'Featured Image', 'catch-everest-pro' )
		),
		'full' => array(
			'id' => 'catcheverest-featured-image',
			'value' => 'full',
			'label' => esc_html__( 'Full Image', 'catch-everest-pro' )
		),
		'slider' => array(
			'id' => 'catcheverest-featured-image',
			'value' => 'slider',
			'label' => esc_html__( 'Slider Image', 'catch-everest-pro' )
		),
		'disable' => array(
			'id' => 'catcheverest-featured-image',
			'value' => 'disable',
			'label' => esc_html__( 'Disable Image', 'catch-everest-pro' )
		)
	);

    // Use nonce for verification
    wp_nonce_field( basename( __FILE__ ), 'custom_meta_box_nonce' );
    ?>
    <p class="post-attributes-label-wrapper"><label class="post-attributes-label" for="catcheverest-sidebarlayout"><?php esc_html_e( 'Sidebar Layout', 'catch-everest-pro' ); ?></label></p>
	<select class="widefat" name="catcheverest-sidebarlayout" id="catcheverest-sidebarlayout">
		 <?php
			$meta_value = get_post_meta( $post->ID, 'catcheverest-sidebarlayout', true );
			
			if ( empty( $meta_value ) ){
				$meta_value = 'default';
			}
			
			foreach ( $sidebar_layout as $field =>$label ) {  
			?>
				<option value="<?php echo esc_attr( $label['value'] ); ?>" <?php selected( $meta_value, $label['value'] ); ?>><?php echo esc_html( $label['label'] ); ?></option>
			<?php
			} // end foreach
		?>
	</select>

	<p class="post-attributes-label-wrapper"><label class="post-attributes-label" for="catcheverest-sidebar-options"><?php esc_html_e( 'Select Sidebar', 'catch-everest-pro' ); ?></label></p>
	<select class="widefat" name="catcheverest-sidebar-options" id="catcheverest-sidebar-options">
		 <?php
			$meta_value = get_post_meta( $post->ID, 'catcheverest-sidebar-options', true );
			
			if ( empty( $meta_value ) ){
				$meta_value = 'default';
			}
			
			foreach ( $sidebar_options as $field =>$label ) {  
			?>
				<option value="<?php echo esc_attr( $label['value'] ); ?>" <?php selected( $meta_value, $label['value'] ); ?>><?php echo esc_html( $label['label'] ); ?></option>
			<?php
			} // end foreach
		?>
	</select>

    <p class="post-attributes-label-wrapper"><label class="post-attributes-label" for="catcheverest-header-image"><?php esc_html_e( 'Header Featured Image Options', 'catch-everest-pro'); ?></label></p>
	<select class="widefat" name="catcheverest-header-image" id="catcheverest-header-image">
		 <?php
			$meta_value = get_post_meta( $post->ID, 'catcheverest-header-image', true );
			
			if ( empty( $meta_value ) ){
				$meta_value = 'default';
			}
			
			foreach ( $header_image_options as $field =>$label ) {  
			?>
				<option value="<?php echo esc_attr( $label['value'] ); ?>" <?php selected( $meta_value, $label['value'] ); ?>><?php echo esc_html( $label['label'] ); ?></option>
			<?php
			} // end foreach
		?>
	</select>

	<p class="post-attributes-label-wrapper"><label class="post-attributes-label" for="catcheverest-featured-image"><?php esc_html_e( 'Content Featured Image Options', 'catch-everest-pro'); ?></label></p>
	<select class="widefat" name="catcheverest-featured-image" id="catcheverest-featured-image">
		 <?php
			$meta_value = get_post_meta( $post->ID, 'catcheverest-featured-image', true );
			
			if ( empty( $meta_value ) ){
				$meta_value = 'default';
			}
			
			foreach ( $featuredimage_options as $field =>$label ) {  
			?>
				<option value="<?php echo esc_attr( $label['value'] ); ?>" <?php selected( $meta_value, $label['value'] ); ?>><?php echo esc_html( $label['label'] ); ?></option>
			<?php
			} // end foreach
		?>
	</select>
<?php
}


/**
 * save the custom metabox data
 * @hooked to save_post hook
 */
function catcheverest_save_custom_meta( $post_id ) {
	global $header_image_options, $sidebar_layout, $sidebar_options, $featuredimage_options, $post;

	// Verify the nonce before proceeding.
    if ( !isset( $_POST[ 'custom_meta_box_nonce' ] ) || !wp_verify_nonce( $_POST[ 'custom_meta_box_nonce' ], basename( __FILE__ ) ) )
        return;

	// Stop WP from clearing custom fields on autosave
    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE)
        return;

	if ('page' == $_POST['post_type']) {
        if ( ! current_user_can( 'edit_page', $post_id ) ) {
            return $post_id;
        }
    } elseif ( ! current_user_can( 'edit_post', $post_id ) ) {
        return $post_id;
    }


	if ( ! update_post_meta ( $post_id, 'catcheverest-header-image', sanitize_key( $_POST['catcheverest-header-image'] ) ) ) {
		add_post_meta( $post_id, 'catcheverest-header-image', sanitize_key( $_POST['catcheverest-header-image'] ), true );
	}

	if ( ! update_post_meta ( $post_id, 'catcheverest-sidebarlayout', sanitize_key( $_POST['catcheverest-sidebarlayout'] ) ) ) {
		add_post_meta( $post_id, 'catcheverest-sidebarlayout', sanitize_key( $_POST['catcheverest-sidebarlayout'] ), true );
	}

	if ( ! update_post_meta ( $post_id, 'catcheverest-sidebar-options', sanitize_key( $_POST['catcheverest-sidebar-options'] ) ) ) {
		add_post_meta( $post_id, 'catcheverest-sidebar-options', sanitize_key( $_POST['catcheverest-sidebar-options'] ), true );
	}

	if ( ! update_post_meta ( $post_id, 'catcheverest-featured-image', sanitize_key( $_POST['catcheverest-featured-image'] ) ) ) {
		add_post_meta( $post_id, 'catcheverest-featured-image', sanitize_key( $_POST['catcheverest-featured-image'] ), true );
	}
}
add_action('save_post', 'catcheverest_save_custom_meta');
